Stan Math Library: stan/math/rev/mat/fun/sum.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
sum.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/arr/fun/sum.hpp>`

Go to the source code of this file.

## Classes
class | stan::math::sum_eigen_v_vari
| Class for representing sums with constructors for Eigen. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C>
var | stan::math::sum (const Eigen::Matrix< var, R, C > &m)
| Returns the sum of the coefficients of the specified matrix, column vector or row vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.